import unittest
import aleixo50

from aleixo50 import rand
from aleixo50.dish import Dish

class RandTest(unittest.TestCase):
    def test_rand_type(self):
        self.assertIsInstance(rand(), Dish)

if __name__ == '__main__':
    unittest.main()



import os
import json
from .dish import Dish

dishes = []

with open(os.path.join(os.path.dirname(__file__),"recipes.json"), 'r') as json_file:
    _recipes = json.loads(json_file.read())

    dishes = [Dish(r['name']) for r in _recipes]




class Dish(object):
    def __init__(self, name, ingredients=[], instructions=[]):
        self.name = name
        self.ingredients = ingredients
        self.instructions = instructions

    def __repr__(self):
        return 'Dish({0.name!r}, {0.ingredients!r}, {0.instructions!r})'.format(self)

    def __str__(self):
        return 'Dish({0.name})'.format(self)





import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="aleixo50",
    version="0.0.3",
    author="André Santos",
    author_email="andrefs@andrefs.com",
    description="Bruno Aleixo's famous 50 Portuguese traditional dishes",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/andrefs/python-aleixo50",
    packages=setuptools.find_packages(),
    scripts=['bin/aleixo50'],
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "Topic :: Utilities"
    ],
)



import unittest
import aleixo50

from aleixo50 import dishes

class RandTest(unittest.TestCase):
    def test_rand_type(self):
        self.assertEqual(len(dishes), 50)

if __name__ == '__main__':
    unittest.main()
